Discover Packages
github.com/gtkit/gouploader
internal
response
package
Version:
v1.3.0
Opens a new window with list of versions in this module.
Published: Apr 30, 2026
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Err 返回错误响应。自动识别 *types.Error 类型。
type Result struct {
Code int `json:"code"`
Message string `json:"message"`
Data any `json:"data,omitempty"`
Details string `json:"details,omitempty"`
}
Result 统一 JSON 响应结构。
Source Files
¶
Click to show internal directories.
Click to hide internal directories.